package com.ruoyi.base.service;

import java.util.List;
import com.ruoyi.base.domain.RobotOpsFaqSimilar;

/**
 * 相似问答表Service接口
 * 
 * @author ruoyi
 * @date 2026-05-07
 */
public interface IRobotOpsFaqSimilarService 
{
    /**
     * 查询相似问答表
     * 
     * @param id 相似问答表主键
     * @return 相似问答表
     */
    public RobotOpsFaqSimilar selectRobotOpsFaqSimilarById(Long id);

    /**
     * 查询相似问答表列表
     * 
     * @param robotOpsFaqSimilar 相似问答表
     * @return 相似问答表集合
     */
    public List<RobotOpsFaqSimilar> selectRobotOpsFaqSimilarList(RobotOpsFaqSimilar robotOpsFaqSimilar);

    /**
     * 新增相似问答表
     * 
     * @param robotOpsFaqSimilar 相似问答表
     * @return 结果
     */
    public int insertRobotOpsFaqSimilar(RobotOpsFaqSimilar robotOpsFaqSimilar);

    /**
     * 修改相似问答表
     * 
     * @param robotOpsFaqSimilar 相似问答表
     * @return 结果
     */
    public int updateRobotOpsFaqSimilar(RobotOpsFaqSimilar robotOpsFaqSimilar);

    /**
     * 批量删除相似问答表
     * 
     * @param ids 需要删除的相似问答表主键集合
     * @return 结果
     */
    public int deleteRobotOpsFaqSimilarByIds(Long[] ids);

    /**
     * 删除相似问答表信息
     * 
     * @param id 相似问答表主键
     * @return 结果
     */
    public int deleteRobotOpsFaqSimilarById(Long id);
}
