package com.ruoyi.web.controller.base;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.base.domain.RobotOpsFaqSimilar;
import com.ruoyi.base.service.IRobotOpsFaqSimilarService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 相似问答表Controller
 *
 * @author ruoyi
 * @date 2026-05-07
 */
@RestController
@RequestMapping("/base/similar")
public class RobotOpsFaqSimilarController extends BaseController
{
    @Autowired
    private IRobotOpsFaqSimilarService robotOpsFaqSimilarService;

    /**
     * 查询相似问答表列表
     */
    @PreAuthorize("@ss.hasPermi('base:similar:list')")
    @GetMapping("/list")
    public TableDataInfo list(RobotOpsFaqSimilar robotOpsFaqSimilar)
    {
        startPage();
        List<RobotOpsFaqSimilar> list = robotOpsFaqSimilarService.selectRobotOpsFaqSimilarList(robotOpsFaqSimilar);
        return getDataTable(list);
    }

    /**
     * 导出相似问答表列表
     */
    @PreAuthorize("@ss.hasPermi('base:similar:export')")
    @Log(title = "相似问答表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RobotOpsFaqSimilar robotOpsFaqSimilar)
    {
        List<RobotOpsFaqSimilar> list = robotOpsFaqSimilarService.selectRobotOpsFaqSimilarList(robotOpsFaqSimilar);
        ExcelUtil<RobotOpsFaqSimilar> util = new ExcelUtil<RobotOpsFaqSimilar>(RobotOpsFaqSimilar.class);
        util.exportExcel(response, list, "相似问答表数据");
    }

    /**
     * 获取相似问答表详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:similar:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(robotOpsFaqSimilarService.selectRobotOpsFaqSimilarById(id));
    }

    /**
     * 新增相似问答表
     */
    @PreAuthorize("@ss.hasPermi('base:similar:add')")
    @Log(title = "相似问答表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RobotOpsFaqSimilar robotOpsFaqSimilar)
    {
        return toAjax(robotOpsFaqSimilarService.insertRobotOpsFaqSimilar(robotOpsFaqSimilar));
    }

    /**
     * 修改相似问答表
     */
    @PreAuthorize("@ss.hasPermi('base:similar:edit')")
    @Log(title = "相似问答表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RobotOpsFaqSimilar robotOpsFaqSimilar)
    {
        return toAjax(robotOpsFaqSimilarService.updateRobotOpsFaqSimilar(robotOpsFaqSimilar));
    }

    /**
     * 删除相似问答表
     */
    @PreAuthorize("@ss.hasPermi('base:similar:remove')")
    @Log(title = "相似问答表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(robotOpsFaqSimilarService.deleteRobotOpsFaqSimilarByIds(ids));
    }
}
